# 🌐 DrugSuperLab

![image](https://github.com/kamangir/assets/blob/main/blue-geo/DrugSuperLab.png?raw=true)

 - [CBC](https://www.cbc.ca/news/canada/british-columbia/drug-superlab-rcmp-bust-falkland-1.7371488): Sleepy little Falkland, B.C., awakes to big news of superlab drug bust
 - [Google Maps](https://maps.app.goo.gl/errDohJAuedpNibs7): `lat: 50.4505"N`, `lon: 119.5060"W`.
 - [RCMP](https://bc-cb.rcmp-grc.gc.ca/ViewPage.action?siteNodeId=2087&languageId=1&contentId=85957): Federal Investigators take down the largest, most sophisticated drug superlab in Canada
 - [YouTube](https://youtu.be/t-POttDl8UQ?t=1876)

---

used by: [`@geo watch`](../../).
